# unzlib
a python command that can decompress the zlib binary data

# Install
```
pip3 install unzlib
```

# Usage
```
# How about use this unzlib repository to test :)
git clone https://github.com/ramwin/unzlib.git && cd unzlib
# You can see the content which is compressed by git easyly.
cat .git/objects/c2/dc76d6e9ecfa41381f20813575f92c538448f4 | unzlib/unzlib.py
```
